This directory contains config information for building packages for different
deployment strategies.

apache
======
This directory contains the config files for deploying edumfa-apache.deb

nginx + uwsgi
=============
These directories contain the config files for deploying edumfa-nginx.deb

edumfa
===========
This directory contains some config examples to be deployed from setup.py
into the python package.
